@@ -22,6 +22,10 @@
 #ifndef _NFT_H_
 #define _NFT_H_
 
-int nft_rulerize(void);
+#include "farms.h"
+
+#define NFTLB_POSTROUTING_MARK		0x80000000
+
+int nft_rulerize(struct farm *f);
 
 #endif /* _NFT_H_ */
